import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:veerne_kit/components/title_item.dart';
import 'package:veerne_kit/controllers/button_controller.dart';
import 'package:veerne_kit/services/routing_service.dart';
import 'package:veerne_kit/types/button_types.dart';

class Button extends StatefulWidget {
  final String title;
  final Function(ButtonController) onTap;
  final EdgeInsets padding;
  final ButtonType type;
  final Color color;

  Button(
      {@required this.title,
      @required this.onTap,
      this.type = ButtonType.primary,
      this.color,
      this.padding = const EdgeInsets.all(1)});

  @override
  _ButtonState createState() => _ButtonState();
}

class _ButtonState extends State<Button> {
  bool isLoading = false;

  void showLoading() => setState(() => isLoading = true);

  void hideLoading() => setState(() => isLoading = false);

  Widget renderContent() {
    final bool isPrimary = widget.type == ButtonType.primary;

    if (isLoading) {
      return SizedBox(
        height: MediaQuery.of(context).size.height * .02,
        width: MediaQuery.of(context).size.height * .02,
        child: CircularProgressIndicator(
          backgroundColor: Colors.white,
        ),
      );
    }

    return Text(widget.title,
        style: TextStyle(
            color: isPrimary ? Colors.black : Colors.white,
            fontWeight: FontWeight.bold));
  }

  void showAlert(String message) {
    showModalBottomSheet(
        context: context,
        builder: (context) {
          return Container(
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.center,
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Icon(Icons.info_outline, color: Colors.black, size: 40),
                TitleItem(
                  message,
                  overflow: TextOverflow.fade,
                  textAlign: TextAlign.center,
                ),
                Divider(),
                FloatingActionButton.extended(
                  onPressed: () => RoutingService.goBack(context),
                  label: Text("Cerrar"),
                  backgroundColor: Colors.redAccent,
                ),
              ],
            ),
          );
        });
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: EdgeInsets.only(top: 3, left: 10, right: 10, bottom: 5),
      child: CupertinoButton(
        borderRadius: BorderRadius.circular(20),
        onPressed: () => this.widget.onTap(ButtonController(
            showLoading: showLoading,
            hideLoading: hideLoading,
            showAlert: showAlert)),
        color: widget.color != null
            ? widget.color
            : Color.fromRGBO(99, 180, 244, 1),
        child: Container(
          alignment: Alignment.center,
          padding: this.widget.padding,
          child: Center(child: renderContent()),
        ),
      ),
    );
  }
}
